# Credits and Licenses

Windows Git package by David Kinder.
Windows Glk is copyright 1998-2016 by David Kinder.
Git is copyright 2003 by Iain Merrick.

License

Both Git and Windows Glk are released under the terms of the MIT license:

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Git Credits

Iain's text file with the Git source code includes the following credits:

Andrew Plotkin invented Glulx, so obviously Git wouldn't exist without him. I also reused some code from his Glulxe interpreter (glkop.c and search.c), which saved me a lot of time and let me concentrate on the more interesting stuff.

Many thanks are due to John Cater, who not only persuaded me to use source control, but let me use his own CVS server. John also provided lots of useful advice and encouragement, as did Sean Barrett.

Thanks also to Joe Mason, Adam Thornton, Simon Baldwin and Joonas Pihlaja who were among the first to try it out and complain that it wasn't working. Joonas also gets special brownie points for trying out more bizarre boundary cases than I realised existed in the first place.

Tor Andersson was apparently the first person to use setmemsize, since he also explained why it didn't work and contributed a fix. Thanks, Tor!

David Kinder has done a stellar job of maintaining the code recently. Thanks also to Eliuk Blau for tracking down bugs in the memory management opcodes.

Windows Glk Credits

The user interface for Windows Glk has been translated into Spanish by Javier San José, and into Italian by Tommaso Caldarola.

Windows Glk contains bitmap scaling code written by Eran Yariv. The code that handles Ogg Vorbis music resources is based on code submitted by David Moreno.

Windows Glk uses the following libraries:

- jpeglib by the Independent JPEG Group.
- libpng by Guy Eric Schalnat, Andreas Dilger, Glenn Randers-Pehrson, and others.
- zlib by Jean-loup Gailly and Mark Adler.
- libogg and libvorbis by the Xiph.org Foundation. (Click here for the license.)
- MODPlug by Olivier Lapicque.